pub struct ColorStop {
pub offset: f32,
pub color: Color,
}Expand description
A point along the gradient vector where the specified color is unmixed.
Fields
offset: f32Offset along the gradient vector.
color: ColorThe color of the gradient at the specified offset.