pub fn sipper<Progress, F>( builder: impl FnOnce(Sender<Progress>) -> F, ) -> impl Sipper<<F as Future>::Output, Progress>where F: Future,
sipper
Creates a new Sipper from the given async closure, which receives a Sender that can be used to notify progress asynchronously.
Sipper
Sender