Content

Struct Content 

pub struct Content { /* private fields */ }
Available on crate feature markdown only.
A bunch of Markdown that has been parsed.

Implementations

Source

impl Content

pub fn new() -> Content

Creates a new empty Content.

pub fn parse(markdown: &str) -> Content

Creates some new Content by parsing the given Markdown.

pub fn code_theme(self, theme: Theme) -> Content

Available on crate feature highlighter only.

Sets the syntax highlighting theme for code blocks.

This only has an effect when the highlighter feature is enabled. Existing code blocks are not re-highlighted; call this before push_str.

pub fn push_str(&mut self, markdown: &str)

Pushes more Markdown into the Content; parsing incrementally!

This is specially useful when you have long streams of Markdown; like big files or potentially long replies.

pub fn items(&self) -> &[Item]

Returns the Markdown items, ready to be rendered.

You can use view to turn them into an Element.

pub fn images(&self) -> &HashSet<String>

Returns the URLs of the Markdown images present in the Content.