pub struct PaneGrid<'a, Message, Theme = Theme, Renderer = Renderer<Renderer, Renderer>>{ /* private fields */ }Expand description
A collection of panes distributed using either vertical or horizontal splits to completely fill the space available.

This distribution of space is common in tiling window managers (like
awesome, i3, or even
tmux).
A PaneGrid supports:
- Vertical and horizontal splits
- Tracking of the last active pane
- Mouse-based resizing
- Drag and drop to reorganize panes
- Hotkey support
- Configurable modifier keys
StateAPI to perform actions programmatically (split,swap,resize, etc.)
Example
use iced::widget::{pane_grid, text};
struct State {
panes: pane_grid::State<Pane>,
}
enum Pane {
SomePane,
AnotherKindOfPane,
}
enum Message {
PaneDragged(pane_grid::DragEvent),
PaneResized(pane_grid::ResizeEvent),
}
fn view(state: &State) -> Element<'_, Message> {
pane_grid(&state.panes, |pane, state, is_maximized| {
pane_grid::Content::new(match state {
Pane::SomePane => text("This is some pane"),
Pane::AnotherKindOfPane => text("This is another kind of pane"),
})
})
.on_drag(Message::PaneDragged)
.on_resize(10, Message::PaneResized)
.into()
}Implementations
Sourceimpl<'a, Message, Theme, Renderer> PaneGrid<'a, Message, Theme, Renderer>
impl<'a, Message, Theme, Renderer> PaneGrid<'a, Message, Theme, Renderer>
Sourcepub fn new<T>(
state: &'a State<T>,
view: impl Fn(Pane, &'a T, bool) -> Content<'a, Message, Theme, Renderer>,
) -> PaneGrid<'a, Message, Theme, Renderer>
pub fn new<T>( state: &'a State<T>, view: impl Fn(Pane, &'a T, bool) -> Content<'a, Message, Theme, Renderer>, ) -> PaneGrid<'a, Message, Theme, Renderer>
Sourcepub fn width(
self,
width: impl Into<Length>,
) -> PaneGrid<'a, Message, Theme, Renderer>
pub fn width( self, width: impl Into<Length>, ) -> PaneGrid<'a, Message, Theme, Renderer>
Sets the width of the PaneGrid.
Sourcepub fn height(
self,
height: impl Into<Length>,
) -> PaneGrid<'a, Message, Theme, Renderer>
pub fn height( self, height: impl Into<Length>, ) -> PaneGrid<'a, Message, Theme, Renderer>
Sets the height of the PaneGrid.
Sourcepub fn spacing(
self,
amount: impl Into<Pixels>,
) -> PaneGrid<'a, Message, Theme, Renderer>
pub fn spacing( self, amount: impl Into<Pixels>, ) -> PaneGrid<'a, Message, Theme, Renderer>
Sets the spacing between the panes of the PaneGrid.
Sourcepub fn min_size(
self,
min_size: impl Into<Pixels>,
) -> PaneGrid<'a, Message, Theme, Renderer>
pub fn min_size( self, min_size: impl Into<Pixels>, ) -> PaneGrid<'a, Message, Theme, Renderer>
Sourcepub fn on_drag<F>(self, f: F) -> PaneGrid<'a, Message, Theme, Renderer>
pub fn on_drag<F>(self, f: F) -> PaneGrid<'a, Message, Theme, Renderer>
Enables the drag and drop interactions of the PaneGrid, which will
use the provided function to produce messages.
Sourcepub fn on_resize<F>(
self,
leeway: impl Into<Pixels>,
f: F,
) -> PaneGrid<'a, Message, Theme, Renderer>where
F: 'a + Fn(ResizeEvent) -> Message,
pub fn on_resize<F>(
self,
leeway: impl Into<Pixels>,
f: F,
) -> PaneGrid<'a, Message, Theme, Renderer>where
F: 'a + Fn(ResizeEvent) -> Message,
Enables the resize interactions of the PaneGrid, which will
use the provided function to produce messages.
The leeway describes the amount of space around a split that can be
used to grab it.
The grabbable area of a split will have a length of spacing + leeway,
properly centered. In other words, a length of
(spacing + leeway) / 2.0 on either side of the split line.
Sourcepub fn on_focus_cycle<F>(self, f: F) -> PaneGrid<'a, Message, Theme, Renderer>
pub fn on_focus_cycle<F>(self, f: F) -> PaneGrid<'a, Message, Theme, Renderer>
Sets the callback for focus cycling via F6 / Shift+F6.
When the user presses F6, the next Pane in order is published.
Shift+F6 cycles in reverse. The application is responsible for
tracking which pane is focused and passing it via
Self::focused_pane.
Sourcepub fn focused_pane(self, pane: Pane) -> PaneGrid<'a, Message, Theme, Renderer>
pub fn focused_pane(self, pane: Pane) -> PaneGrid<'a, Message, Theme, Renderer>
Sets the currently focused Pane.
This is used by Self::on_focus_cycle to determine the starting
point when cycling panes with F6 / Shift+F6. If no pane is focused,
cycling starts from the first pane.