Svg

Struct Svg 

pub struct Svg<'a, Theme = Theme>
where Theme: Catalog,
{ /* private fields */ }
A vector graphics image.

An Svg image resizes smoothly without losing any quality.

Svg images can have a considerable rendering cost when resized, specially when they are complex.

Example

use iced::widget::svg;

enum Message {
    // ...
}

fn view(state: &State) -> Element<'_, Message> {
    svg("tiger.svg").into()
}

Implementations

Source

impl<'a, Theme> Svg<'a, Theme>
where Theme: Catalog,

pub fn new(handle: impl Into<Handle>) -> Svg<'a, Theme>

Available on crate feature svg only.

Creates a new Svg from the given Handle.

pub fn from_path(path: impl Into<PathBuf>) -> Svg<'a, Theme>

Available on crate feature svg only.

Creates a new Svg that will display the contents of the file at the provided path.

pub fn width(self, width: impl Into<Length>) -> Svg<'a, Theme>

Available on crate feature svg only.

Sets the width of the Svg.

pub fn height(self, height: impl Into<Length>) -> Svg<'a, Theme>

Available on crate feature svg only.

Sets the height of the Svg.

pub fn content_fit(self, content_fit: ContentFit) -> Svg<'a, Theme>

Available on crate feature svg only.

Sets the ContentFit of the Svg.

Defaults to ContentFit::Contain

pub fn style( self, style: impl Fn(&Theme, Status) -> Style + 'a, ) -> Svg<'a, Theme>
where <Theme as Catalog>::Class<'a>: From<Box<dyn Fn(&Theme, Status) -> Style + 'a>>,

Available on crate feature svg only.

Sets the style of the Svg.

pub fn class( self, class: impl Into<<Theme as Catalog>::Class<'a>>, ) -> Svg<'a, Theme>

Available on crate features svg and advanced only.

Sets the style class of the Svg.

pub fn rotation(self, rotation: impl Into<Rotation>) -> Svg<'a, Theme>

Available on crate feature svg only.

Applies the given Rotation to the Svg.

pub fn opacity(self, opacity: impl Into<f32>) -> Svg<'a, Theme>

Available on crate feature svg only.

Sets the opacity of the Svg.

It should be in the [0.0, 1.0] range—0.0 meaning completely transparent, and 1.0 meaning completely opaque.

pub fn alt(self, text: impl Into<String>) -> Svg<'a, Theme>

Available on crate feature svg only.

Sets the alt text of the Svg.

This is the accessible name announced by screen readers. It should be a short phrase describing the image content.

pub fn description(self, description: impl Into<String>) -> Svg<'a, Theme>

Available on crate feature svg only.

Sets an extended description of the Svg.

This supplements the alt text with additional context for assistive technology, when the alt text alone is not sufficient.