Module task

Module task 

Create runtime tasks.

Structs

Handle
A handle to a Task that can be used for aborting it.
Task
A set of concurrent actions to be performed by the iced runtime.

Traits

Sippersipper
A sipper is both a Stream that produces a bunch of progress and a Future that produces some final output.
Strawsipper
A Straw is a Sipper that can fail.

Functions

sippersipper
Creates a new Sipper from the given async closure, which receives a Sender that can be used to notify progress asynchronously.
streamsipper
Turns a Sipper into a Stream.

Type Aliases

Neversipper
A type with no possible values.